#!/bin/sh

mtconf="/var/packages/iTunesServer/etc/mt-daapd.conf"
mtplaylist="/etc/mt-daapd.playlist"
HostName=`/bin/cat /etc/hostname`
servername="servername	$HostName"
PidFile="/var/run/mt-daapd.pid"

CreateDefaultConf()
{
	echo "$servername" > $mtconf
	/usr/bin/chown iTunesServer:iTunesServer $mtconf
}

if [ ! -f "$mtconf" ]; then
	CreateDefaultConf
fi
if [ ! -f "$mtplaylist" ]; then
	touch $mtplaylist
fi

# check mt-daapd.conf content
testLine=$(grep "servername	." $mtconf)
if [ -z "$testLine" ]; then
	# reset mt-daapd.conf to HostName
	CreateDefaultConf
fi

Stop()
{
	[ -f "$PidFile" ] || exit
	Pid=`cat $PidFile`
	if [ -d "/proc/$Pid/" ]; then
		kill -TERM $Pid > /dev/null 2>&1
	fi

	# check whether the mt-daapd is alive
	Count=1
	IsAlive=1
	while [  $Count -le 20 ]
	do
		if [ ! -d "/proc/$Pid/" ]; then
			IsAlive=0
			break;
		fi
		
		Count=`expr $Count + 1`
		sleep 1
	done

	if [ $IsAlive = 1 ]; then
		kill -9 $Pid > /dev/null 2>&1
	fi

	echo "iTunes Server stopped"
}

mtdaapd="/var/packages/iTunesServer/target/sbin/mt-daapd"
Start()
{
	if [ ! -x "$mtdaapd" ]; then
		echo "$iTunes server daemons don't exist!"
		exit 2
	fi

	/usr/syno/sbin/synoservicecfg --is-enabled pgsql
	# in service framework, function 'is-enabled' will retrun 1 if service is enabled
	# $? == 0 means service is not enabled
	if [ $? -eq 0 ]; then
		echo "PGSQL is not enabled"
		exit 1;
	fi

	killall -0 mt-daapd 2>/dev/null || $mtdaapd
	echo "iTunes Server started"
	sleep 3
}

case $1 in
start)
	Start
	;;

stop)
	Stop
	;;

restart)
	Stop
	sleep 1
	Start
	;;

*)
	echo "usage: `basename $0` {start|stop|restart}" >&2
	exit 64
	;;
esac
exit 0
